Learn R Programming

SurprisalAnalysis (version 3.0.0)

runSurprisalApp: Launch the SurprisalAnalysis Shiny App

Description

Launch the SurprisalAnalysis Shiny App

Usage

runSurprisalApp(
  port = getOption("shiny.port", 3838),
  host = getOption("shiny.host", "127.0.0.1"),
  launch.browser = getOption("shiny.launch.browser", TRUE),
  run = TRUE,
  ...
)

Value

no return value, running the function will launch an application with graphical user interface

Arguments

port

port to run the app on (passed to shiny::runApp)

host

host to listen on

launch.browser

should launch a browser? set to TRUE by default

run

boolean value, is set to TRUE by default. If set to FALSE it will not launch the graphical user interface

...

Further arguments passed along to shiny::runApp

Examples

Run this code

runSurprisalApp(port = httpuv::randomPort(), run = FALSE)

Run the code above in your browser using DataLab