powered by
Launch the SurprisalAnalysis Shiny App
runSurprisalApp( port = getOption("shiny.port", 3838), host = getOption("shiny.host", "127.0.0.1"), launch.browser = getOption("shiny.launch.browser", TRUE), run = TRUE, ... )
no return value, running the function will launch an application with graphical user interface
port to run the app on (passed to shiny::runApp)
host to listen on
should launch a browser? set to TRUE by default
boolean value, is set to TRUE by default. If set to FALSE it will not launch the graphical user interface
Further arguments passed along to shiny::runApp
runSurprisalApp(port = httpuv::randomPort(), run = FALSE)
Run the code above in your browser using DataLab